#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

with open('requirements.txt') as f:
    requirements = f.read().split('\n')

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='parthsql',
    version='0.1.0',
    description="A mini SQL query engine written in Python",
    long_description=readme + '\n\n' + history,
    author="Parth Kolekar",
    author_email='parth.kolekar@students.iiit.ac.in',
    url='https://github.com/ParthKolekar/parthsql',
    packages=[
        'parthsql',
    ],
    package_dir={'parthsql':
                 'parthsql'},
    include_package_data=True,
    install_requires=requirements,
    license="ISCL",
    zip_safe=False,
    keywords='parthsql',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    entry_points={
        'console_scripts': [
            'parthsql=parthsql.main:main',
        ],
    }
)
